import { useLocale, useTranslations } from 'next-intl';
import { Link } from '@/i18n/navigation';
import Image from 'next/image';

import LanguageSwitcher from '@/app/ui/components/LanguageSwitcher';
import { generateAuthUrl } from '@/app/helpers/generateAuthUrl';
import { LocaleType } from '@/i18n/i18n';

export default function Header() {
  const t = useTranslations();
  const locale = useLocale();
  const loginUrl = generateAuthUrl(locale as LocaleType, 'login');

  return (
    <header className="main-header">
        <div className="main-header-content">
            <div className="main-header-left">
                <Link href="/" className="header-logo">
                    <Image src="/img/ui/logo_full.svg" alt="mssg.me logo" width={151} height={44} />
                </Link>
            </div>
            <div className="main-header-right">
                <div className="header-buttons">
                    <ul
                        className="lang-chooser-list lang-chooser-list-desktop"
                        style={{ margin: '0 10px 0 0', lineHeight: '26px' }}
                    >
                        <LanguageSwitcher />
                    </ul>
                    <Link href={loginUrl} className="button button-header button-outline">{t('button.login')}</Link>
                </div>
                <div className="mobile-menu-btn">
                    <div className="mobile-menu-btn-inner">
                        <div></div>
                        <div></div>
                        <div></div>
                    </div>
                </div>
            </div>
        </div>
    </header>
  );
}
