import { getTranslations, getLocale } from 'next-intl/server';
import Link from 'next/link';
import React from 'react';
import { Metadata } from 'next';

interface PostCategory {
  name: string;
}

interface Post {
  title: {
    rendered: string;
  };
  thumbnail_medium_url: string;
  post_categories: PostCategory[];
  acf: {
    time_to_read: string;
  };
  slug: string;
}

export async function generateMetadata(): Promise<Metadata> {
  const locale = await getLocale();
  const t = await getTranslations({ locale });

  return {
    title: t('blog.title'),
    description: t('blog.description'),
  };
}

export default async function Page() {
  const locale = await getLocale();
  const data = await fetch(`https://w.mssg.me/${locale}/wp-json/wp/v2/posts`);
  const posts: Post[] = await data.json();


  return (
        <div className="page-wrapper">
        <section className="section-category-blog">
            <div className="common-content">
                <div className="section-category-blog-content">
                    <ul className="section-fp-news-list section-category-blog-list">
                        {posts.map((element: Post, index: number) =>
                            <li key={index}>
                                <div className="section-fp-news-list-item-preview">
                                    <img src={element.thumbnail_medium_url} alt={element.title.rendered} />
                                </div>
                                <div className="section-fp-news-list-item-content">
                                    <h4>{element.title.rendered}</h4>
                                    <span>
                                        {element.post_categories.map((cat: PostCategory, index: number) =>
                                            <React.Fragment key={index}>
                                                <span>{cat.name}</span> | {element.acf.time_to_read}
                                            </React.Fragment>
                                        )}
                                    </span>
                                </div>
                                <Link href={`/blog/${element.slug}`} className="section-fp-news-list-item-link" />
                            </li>
                        )}
                    </ul>
                </div>
            </div>
        </section>
    </div>
  );
}
