import { getLocale } from 'next-intl/server';

interface AnswerBlock {
  acf_fc_layout: string;
  text?: string;
  heading?: string;
  content?: string;
}

interface Question {
  question: string;
  answer: AnswerBlock[];
}

interface FaqTopic {
  topic_name: string;
  topic_icon_new: string;
  topic_icon_new_active: string;
  topic_subheading?: string;
  'qa-list': Question[];
}

interface PageData {
  acf: {
    faq_topics: FaqTopic[];
  };
}

export default async function Page() {
  const locale = await getLocale();
  const data = await fetch(`https://w.mssg.me/${locale}/wp-json/wp/v2/pages/993`);
  const pData: PageData = await data.json();


  return (
    <div className="page-wrapper">
        <main>
            <div className="page-faq">
                <div className="common-content">
                    <div className="page-faq-content">
                        <article className="page-faq-container">
                            <div className="faq-container">
                                <div className="faq-container-left">
                                    <ul className="faq-top-controls-list clearfix">
                                        {
                                            pData.acf.faq_topics.map((element: FaqTopic) => (
                                                <li key={element.topic_name}>
                                                    <img src={element.topic_icon_new} className="default" alt={element.topic_name} />
                                                    <img src={element.topic_icon_new_active} className="active" alt={element.topic_name} />
                                                    <h2>{element.topic_name}</h2>
                                                    {/* <p>{element.topic_subheading}</p> */}
                                                </li>
                                            ))
                                        }
                                    </ul>
                                </div>
                                <div className="faq-container-right">
                                    <ul className="faq-sublists clearfix">
                                        {pData.acf.faq_topics.map((element: FaqTopic, indexOuter: number) =>
                                            <li key={indexOuter}>
                                                <ul className="faq-panes-list">
                                                    {element['qa-list'].map((question: Question, index: number) =>
                                                        <li id={`${indexOuter+1}-${index+1}`} key={index}>
                                                            <div className="faq-panes-list-item-header">
                                                                <span className="faq-panes-list-item-counter"></span>
                                                                <h3>{question.question}</h3>
                                                                <span className="faq-panes-list-item-status"></span>
                                                            </div>
                                                            <div className="faq-panes-list-item-content">
                                                                {question.answer.map((block: AnswerBlock, index: number) => {
                                                                    if (block.acf_fc_layout === 'text') { 
                                                                        return <div key={index} dangerouslySetInnerHTML={{ __html: block.text || '' }} />;
                                                                    }
                                                                    if (block.acf_fc_layout === 'accordeon') {
                                                                        return (
                                                                            <div key={index} style={{ marginBottom: 6 }}>
                                                                                <div className="accordeon-header">
                                                                                    <h4 className="accordeon-heading">
                                                                                        {block.heading}
                                                                                    </h4>
                                                                                    <span className="faq-panes-list-item-status"></span>
                                                                                </div>
                                                                                <div className="accordeon-content" dangerouslySetInnerHTML={{ __html: block.content || '' }} />
                                                                            </div>
                                                                        )
                                                                     }
                                                                })}
                                                            </div>
                                                        </li>
                                                    )}
                                                </ul>
                                            </li>
                                        )}
                                    </ul>
                                </div>
                            </div>
                        </article>
                    </div>
                </div>
            </div>
        </main>
    </div>
  );
}
