import { getTranslations, getLocale } from 'next-intl/server';
import Link from 'next/link';
import React from 'react';
import { Metadata } from 'next';
import '@/app/ui/wppages/css/index.css';

export async function generateMetadata(): Promise<Metadata> {
  const locale = await getLocale();
  const t = await getTranslations({ locale });

  return {
    title: t('404.heading'),
    description: t('404.error'),
  };
}

export default async function NotFound() {
  const locale = await getLocale();
  const t = await getTranslations({ locale });

  return (
    <html lang={locale}>
      <body>
        <div className="page-wrapper">
            <div className="header-404">
                <Link href="/" className="header-404-logo">
                    <img src="/img/ui/logo_full.svg" alt="mssg.me logo" />
                </Link>
            </div>
            <div className="content-404">
                <div className="content-404-block">
                    <h1>{t('404.heading')}</h1>
                    <p>{t('404.error')}</p>
                    <Link href="/" className="button button-outline">{t('404.button')}</Link>
                </div>
            </div>
        </div>
      </body>
    </html>
  );
}
