'use client';

import { useEffect } from 'react';

export default function MainScripts() {
  useEffect(() => {
    // Fixed header
    const handleScroll = () => {
      const header = document.querySelector('.main-header');
      if (header) {
        if (window.scrollY > 0) {
          header.classList.add('fixed');
        } else {
          header.classList.remove('fixed');
        }
      }
    };

    window.addEventListener('scroll', handleScroll);
    handleScroll(); // Initial check

    // Share popup function
    const windowPopup = (url: string, width: number, height: number) => {
      const left = screen.width / 2 - width / 2;
      const top = screen.height / 2 - height / 2;

      window.open(
        url,
        '',
        `menubar=no,toolbar=no,resizable=yes,scrollbars=yes,width=${width},height=${height},top=${top},left=${left}`
      );
    };

    // Share popup on click
    const shareLinks = document.querySelectorAll('.article-share-list > li > a');
    const handleShareClick = (e: Event) => {
      e.preventDefault();
      const target = e.currentTarget as HTMLAnchorElement;
      if (target?.href) {
        windowPopup(target.href, 500, 300);
      }
    };

    shareLinks.forEach(link => {
      link.addEventListener('click', handleShareClick);
    });

    // FAQ slider functionality
    const initFaqSlider = () => {
      const topControls = document.querySelectorAll('.faq-top-controls-list > li');
      const sliderList = document.querySelector('.faq-sublists') as HTMLElement;
      const sliderListItems = document.querySelectorAll('.faq-sublists > li') as NodeListOf<HTMLElement>;
      const questionPanes = document.querySelectorAll('.faq-panes-list > li');
      const hash = location.hash.substr(2);

      if (!topControls.length || !sliderList || !sliderListItems.length) return;

      // Build initial state
      topControls[0]?.classList.add('active');
      sliderListItems[0]?.classList.add('active');
      
      const parentWidth = sliderList.parentElement?.offsetWidth || 0;
      sliderListItems.forEach(item => {
        item.style.width = `${parentWidth}px`;
      });

      // Scroll to hash in URL
      if (hash !== '') {
        const listIndex = parseInt(hash.substring(0, hash.indexOf('-'))) - 1;
        const questionItem = document.getElementById(hash);

        if (listIndex >= 0 && questionItem) {
          topControls.forEach((control, index) => {
            control.classList.toggle('active', index === listIndex);
          });
          sliderListItems.forEach((item, index) => {
            item.classList.toggle('active', index === listIndex);
          });
          
          const itemWidth = sliderListItems[0]?.offsetWidth || 0;
          sliderList.style.transform = `translateX(-${listIndex * itemWidth}px)`;
          
          questionItem.classList.add('opened');
          const answer = questionItem.querySelector('.faq-panes-list-item-content') as HTMLElement;
          if (answer) {
            answer.style.display = 'block';
          }
          
          setTimeout(() => {
            const header = document.querySelector('.main-header') as HTMLElement;
            const headerHeight = header?.offsetHeight || 0;
            window.scrollTo({
              top: questionItem.offsetTop - headerHeight - 30,
              behavior: 'smooth'
            });
          }, 1300);
        }
      }

      // Fixed topics on desktop
      const handleFaqScroll = () => {
        if (window.innerWidth > 1239) {
          const faqControls = document.querySelector('.faq-top-controls-list');
          if (faqControls) {
            if (window.scrollY > 70) {
              faqControls.classList.add('fixed');
            } else {
              faqControls.classList.remove('fixed');
            }
          }
        }
      };

      window.addEventListener('scroll', handleFaqScroll);

      // Rebuild on resize
      const handleResize = () => {
        const parentWidth = sliderList.parentElement?.offsetWidth || 0;
        sliderListItems.forEach(item => {
          item.style.width = `${parentWidth}px`;
        });
      };

      window.addEventListener('resize', handleResize);

      // Top slider controls event
      const handleTopControlClick = (e: Event) => {
        const target = e.currentTarget as HTMLElement;
        const thisIndex = Array.from(topControls).indexOf(target);
        
        topControls.forEach((control, index) => {
          control.classList.toggle('active', index === thisIndex);
        });
        sliderListItems.forEach((item, index) => {
          item.classList.toggle('active', index === thisIndex);
        });
        
        const itemWidth = sliderListItems[0]?.offsetWidth || 0;
        sliderList.style.transform = `translateX(-${thisIndex * itemWidth}px)`;
        
        questionPanes.forEach(pane => {
          pane.classList.remove('opened');
          const answer = pane.querySelector('.faq-panes-list-item-content') as HTMLElement;
          if (answer) {
            answer.style.display = 'none';
          }
        });
        
        if (window.scrollY > 0) {
          window.scrollTo({ top: 0, behavior: 'smooth' });
        }
      };

      topControls.forEach(control => {
        control.addEventListener('click', handleTopControlClick);
      });

      // Question pane heading click
      const questionHeadings = document.querySelectorAll('.faq-panes-list-item-header');
      const handleQuestionClick = (e: Event) => {
        const target = e.currentTarget as HTMLElement;
        const parentLi = target.closest('li');
        const answer = target.nextElementSibling as HTMLElement;
        
        if (parentLi && answer) {
          window.location.hash = `#q${parentLi.id}`;
          
          if (parentLi.classList.contains('opened')) {
            parentLi.classList.remove('opened');
            answer.style.display = 'none';
          } else {
            parentLi.classList.add('opened');
            answer.style.display = 'block';
          }
        }
      };

      questionHeadings.forEach(heading => {
        heading.addEventListener('click', handleQuestionClick);
      });

      // Accordion functionality
      const accordionHeaders = document.querySelectorAll('.accordeon-header');
      const handleAccordionClick = (e: Event) => {
        const target = e.currentTarget as HTMLElement;
        const content = target.nextElementSibling as HTMLElement;
        
        if (content) {
          if (target.classList.contains('visible')) {
            content.style.display = 'none';
          } else {
            content.style.display = 'block';
          }
          target.classList.toggle('visible');
        }
      };

      accordionHeaders.forEach(header => {
        header.addEventListener('click', handleAccordionClick);
      });

      return () => {
        window.removeEventListener('scroll', handleFaqScroll);
        window.removeEventListener('resize', handleResize);
        topControls.forEach(control => {
          control.removeEventListener('click', handleTopControlClick);
        });
        questionHeadings.forEach(heading => {
          heading.removeEventListener('click', handleQuestionClick);
        });
        accordionHeaders.forEach(header => {
          header.removeEventListener('click', handleAccordionClick);
        });
      };
    };

    // Initialize FAQ slider if container exists
    const faqContainer = document.querySelector('.faq-container-right');
    let faqCleanup: (() => void) | undefined;
    if (faqContainer) {
      faqCleanup = initFaqSlider();
    }

    // Pricing FAQ list
    const pricingFaqItems = document.querySelectorAll('.section-page-pricing-faq-list > li');
    if (pricingFaqItems.length > 0) {
      const firstItem = pricingFaqItems[0];
      const firstHeader = firstItem.querySelector('h4');
      const firstContent = firstItem.querySelector('.section-page-pricing-faq-list-item-content') as HTMLElement;
      
      if (firstHeader && firstContent) {
        firstHeader.classList.add('active');
        firstContent.style.display = 'block';
      }
    }

    const handlePricingFaqClick = (e: Event) => {
      const target = e.currentTarget as HTMLElement;
      const content = target.nextElementSibling as HTMLElement;
      
      if (content) {
        if (target.classList.contains('active')) {
          target.classList.remove('active');
          content.style.display = 'none';
        } else {
          target.classList.add('active');
          content.style.display = 'block';
        }
      }
    };

    const pricingFaqHeaders = document.querySelectorAll('.section-page-pricing-faq-list > li > h4');
    pricingFaqHeaders.forEach(header => {
      header.addEventListener('click', handlePricingFaqClick);
    });

    // Mobile menu
    const handleMobileMenuClick = (e: Event) => {
      const target = e.currentTarget as HTMLElement;
      const mobileMenu = document.querySelector('.mobile-menu');
      const body = document.body;
      
      if (target.classList.contains('active')) {
        target.classList.remove('active');
        mobileMenu?.classList.remove('active');
        body.classList.remove('overflow-hidden');
      } else {
        target.classList.add('active');
        mobileMenu?.classList.add('active');
        body.classList.add('overflow-hidden');
      }
    };

    const mobileMenuBtn = document.querySelector('.mobile-menu-btn');
    if (mobileMenuBtn) {
      mobileMenuBtn.addEventListener('click', handleMobileMenuClick);
    }

    // Pricing switcher
    const handleSwitcherClick = (e: Event) => {
      const target = e.currentTarget as HTMLElement;
      const priceEl = document.getElementById('price');
      
      if (priceEl) {
        const priceMonthly = priceEl.getAttribute('data-price-monthly');
        const priceAnnually = priceEl.getAttribute('data-price-annually');
        const price = target.classList.contains('active') ? priceAnnually : priceMonthly;
        
        target.classList.toggle('active');
        priceEl.innerHTML = price || '';
      }
    };

    const switcher = document.getElementById('switcher');
    if (switcher) {
      switcher.addEventListener('click', handleSwitcherClick);
    }

    // Cookie functions
    const setCookie = (name: string, value: string, days: number) => {
      let expires = '';
      if (days) {
        const date = new Date();
        date.setTime(date.getTime() + days * 24 * 60 * 60 * 1000);
        expires = '; expires=' + date.toUTCString();
      }
      document.cookie = name + '=' + (value || '') + expires + '; path=/';
    };

    const getCookie = (name: string): string | null => {
      const nameEQ = name + '=';
      const ca = document.cookie.split(';');
      for (let i = 0; i < ca.length; i++) {
        let c = ca[i];
        while (c.charAt(0) === ' ') c = c.substring(1, c.length);
        if (c.indexOf(nameEQ) === 0) return c.substring(nameEQ.length, c.length);
      }
      return null;
    };

    // Article links with images no underline
    const articleText = document.querySelector('.section-article-text');
    if (articleText) {
      const articleLinks = articleText.querySelectorAll('a');
      articleLinks.forEach(link => {
        if (link.querySelector('img')) {
          link.classList.add('no-underline');
        }
      });
    }

    // Language chooser
    const handleLanguageChange = (e: Event) => {
      const target = e.currentTarget as HTMLElement;
      const destinationLang = target.getAttribute('data-lang');
      if (destinationLang) {
        setCookie('lang', destinationLang, 7);
      }
    };

    const langChoosers = document.querySelectorAll('.lang-chooser');
    langChoosers.forEach(chooser => {
      chooser.addEventListener('click', handleLanguageChange);
    });

    // Cookie acceptance
    const termsAccepted = getCookie('terms_accept');
    const cookieMessage = document.getElementById('cookie-message');
    
    if (!termsAccepted && cookieMessage) {
      cookieMessage.classList.add('visible');

      const handleCloseCookie = () => {
        setCookie('terms_accept', 'true', 365);

        if (window.innerWidth > 767) {
          cookieMessage.style.transform = 'translateY(100px)';
          cookieMessage.style.opacity = '0';
        } else {
          cookieMessage.style.transform = 'translateY(-100px)';
          cookieMessage.style.opacity = '0';
        }

        setTimeout(() => {
          cookieMessage.remove();
        }, 400);
      };

      const closeCookieBtn = document.getElementById('close-cookie');
      if (closeCookieBtn) {
        closeCookieBtn.addEventListener('click', handleCloseCookie);
      }
    } else if (cookieMessage) {
      cookieMessage.remove();
    }

    // Cleanup function
    return () => {
      window.removeEventListener('scroll', handleScroll);
      shareLinks.forEach(link => {
        link.removeEventListener('click', handleShareClick);
      });
      pricingFaqHeaders.forEach(header => {
        header.removeEventListener('click', handlePricingFaqClick);
      });
      if (mobileMenuBtn) {
        mobileMenuBtn.removeEventListener('click', handleMobileMenuClick);
      }
      if (switcher) {
        switcher.removeEventListener('click', handleSwitcherClick);
      }
      langChoosers.forEach(chooser => {
        chooser.removeEventListener('click', handleLanguageChange);
      });
      if (faqCleanup) {
        faqCleanup();
      }
    };
  }, []);

  return null; // This component doesn't render anything
}
