"use client";
import { useEffect } from 'react';
import lax from 'lax.js';

function setCookie(name: string, value: string, days: number) {
    let expires = '';
    if (days) {
        const date = new Date();
        date.setTime(date.getTime() + days * 24 * 60 * 60 * 1000);
        expires = '; expires=' + date.toUTCString();
    }
    document.cookie = name + '=' + (value || '') + expires + '; path=/';
}

function getCookie(name: string) {
    const nameEQ = name + '=';
    const ca = document.cookie.split(';');
    for (let i = 0; i < ca.length; i++) {
        let c = ca[i];
        while (c.charAt(0) == ' ') c = c.substring(1, c.length);
        if (c.indexOf(nameEQ) == 0) return c.substring(nameEQ.length, c.length);
    }
    return null;
}

export default function MainEffects() {
    useEffect(() => {
        // Cookie message logic
        const cookieMessageEl = document.getElementById('cookie-message');
        const closeCookieIconEl = document.getElementById('close-cookie');
        const termsAccepted = getCookie('terms_accept');
        if (cookieMessageEl && closeCookieIconEl) {
            if (!termsAccepted) {
                cookieMessageEl.classList.add('visible');
                closeCookieIconEl.addEventListener('click', function handler() {
                    setCookie('terms_accept', 'true', 365);
                    cookieMessageEl.classList.add('hide');
                    setTimeout(function() {
                        cookieMessageEl.remove();
                    }, 400);
                    closeCookieIconEl.removeEventListener('click', handler);
                });
            } else {
                cookieMessageEl.remove();
            }
        }
        const langClick = (e: Event) => {
            const target = e.target as HTMLElement;
            const lang = target.getAttribute('data-tolang');
            if (lang === 'ru' || lang === 'en') {
                setCookie('lang', lang, 7);
            }
        };
        document.addEventListener('click', langClick);

        // Lax.js logic
        lax.init();
        lax.addDriver('scrollY', () => window.scrollY);
        lax.addElements(
            '.presentation-hero-left, .presentation-hero-right',
            {
                scrollY: {
                    translateZ: [['elInY', 'elCenterY', 'elOutY'], [-50, -1, -1]],
                    translateY: [['elInY', 'elCenterY', 'elOutY'], [40, 0, -30]],
                    scale: [['elInY', 'elCenterY', 'elOutY'], [0.9, 1, 1]],
                    rotateX: [['elInY', 'elCenterY', 'elOutY'], [20, 0, 0]],
                },
            }
        );
        lax.addElements(
            '.presentation-hero-center, .multi-link-hero > img, .messengers-hero > img, .store-hero > img, .builder-hero > img',
            {
                scrollY: {
                    translateY: [['elInY', 'elCenterY', 'elOutY'], [10, 0, -20]],
                    rotateX: [['elInY', 'elCenterY', 'elOutY'], [20, 0, 0]],
                },
            }
        );
        lax.addElements(
            '.multi-link-hero__icon',
            {
                scrollY: {
                    translateZ: [['elInY', 'elCenterY', 'elOutY'], [50, 1, 1]],
                    rotateX: [['elInY', 'elCenterY', 'elOutY'], [20, 0, 0]],
                },
            }
        );
        lax.addElements(
            '.icon-hey, .message, .icon-cart, .order, .customize',
            {
                scrollY: {
                    translateZ: [['elInY', 'elCenterY', 'elOutY'], [50, 1, 1]],
                    rotateX: [['elInY', 'elCenterY', 'elOutY'], [20, 0, 0]],
                    translateY: [['elInY', 'elCenterY', 'elOutY'], [80, 0, -60]],
                },
            }
        );
        lax.addElements(
            '.blocks',
            {
                scrollY: {
                    translateZ: [['elInY', 'elCenterY', 'elOutY'], [-50, -1, -1]],
                    rotateX: [['elInY', 'elCenterY', 'elOutY'], [20, 0, 0]],
                    translateY: [['elInY', 'elCenterY', 'elOutY'], [80, 0, -60]],
                },
            }
        );
        setTimeout(function() {
            document.querySelectorAll('.presentation-hero > img').forEach(function(el) {
                el.classList.add('no-transition');
            });
        }, 600);

        // Cleanup
        return () => {
            document.removeEventListener('click', langClick);
        };
    }, []);
    return null;
}
